.. _.readthedocs.yaml-name:

!!!!!!!!!!!!!!!!!
.readthedocs.yaml
!!!!!!!!!!!!!!!!!

.. meta::
  :keywords: .readthedocs.yaml,example,read,the,docs,configuration,specification,this,file

.. index:: .readthedocs.yaml, read, docs, configuration

.. _.readthedocs.yaml-title:

Example Read the Docs Configuration
###################################

.. contents::
  :local:

.. index:: read, docs, specification

.. _.readthedocs.yaml@Read the Docs Specification:

Read the Docs Specification
***************************
`<https://docs.readthedocs.io/en/stable/config-file>`_

.. _.readthedocs.yaml@This Example File:

This Example File
*****************

.. literalinclude:: ../../.readthedocs.yaml
  :language: yaml
